==> bacula-3.0.3.tar.gz: bacula-3.0.3/src/win32/libwin32/res.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation, which is 
   listed in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of Kern Sibbald.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 * Kern Sibbald, August 2007
 *
 *   Version $Id$
 */

/* Icon definitions */
#define IDI_BACULA             100
#define IDI_IDLE               101
#define IDI_RUNNING            102
#define IDI_JOB_ERROR          103
#define IDI_JOB_WARNING        104
#define IDR_TRAYMENU           105
#define IDB_BACULABMP          106

#define IDC_TEXTDISPLAY       1000

#define ID_ABOUT             40000
#define ID_STATUS            40001
#define ID_CLOSE             40002

/* Dialog definitions */
#define IDD_ABOUT              201
#define IDD_STATUS             202

==> bacula-5.2.2.tar.gz: bacula-5.2.2/src/win32/libwin32/res.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version three of the GNU Affero General Public
   License as published by the Free Software Foundation, which is 
   listed in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU Affero General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of Kern Sibbald.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 * Kern Sibbald, August 2007
 *
 *   Version $Id$
 */

/* Icon definitions */
#define IDI_BACULA             100
#define IDI_IDLE               101
#define IDI_RUNNING            102
#define IDI_JOB_ERROR          103
#define IDI_JOB_WARNING        104
#define IDR_TRAYMENU           105
#define IDB_BACULABMP          106

#define IDC_TEXTDISPLAY       1000

#define ID_ABOUT             40000
#define ID_STATUS            40001
#define ID_CLOSE             40002

/* Dialog definitions */
#define IDD_ABOUT              201
#define IDD_STATUS             202
